
<h1 align="center">

<img src="https://img.shields.io/static/v1?label=DIGITSSUM%20POR&message=bates&color=7159c1&style=flat-square&logo=ghost"/>

<h3> <p align="center">DIGITS SUM </p> </h3>

<h3> <p align="center"> ================= </p> </h3>

>> <h3> Resume </h3>

<p> The <b> digitsSum() </b> function is a function that adds the digits of an integer and can return the result with a custom amount of decimal places.

Basically, you call the function with an integer, and it returns the sum of its digits. But if you want a result with a specific number of decimal places, just pass an optional second argument to the function.

For example, if you want to know the sum of the digits of 88, just call <b> digitsSum(88) </b> and the function will return 16. But if you want the result to have only one decimal place, just call <b> digitsSum(88, False ) </b> and the function will return 7.

And best of all, the function is very simple and easy to understand, even if you're not a programming expert! </p>

>> <h3> How install </h3>

```

pip install digitsSum

```

>> <h3> How Works </h3>

```

from digitsSum import *

#a = digitsSum(127) # get an answer with two decimal places
#a = digitSum(127,False) # get the sum of all values until you get only one digit

#print(a)
```
    